##### Package <em>apb_pandas_utils</em>

Modules to add functionality over `pandas` and `geopandas` 

To install:
```shell
pip install "git+https://github.com/portdebarcelona/PLANOL-generic_python_packages#egg=apb_pandas_utils&subdirectory=apb_pandas_utils_pckg"
```
